# Bluetooth BLE for Human Beings

This is a simple library for interacting with BLE devices. It is
designed to be easy to use and understand, and to be a good starting point for building your own BLE applications.

This library is based on [BLEAK](https://bleak.readthedocs.io/en/latest/).

- [x] Discovering devices and simple filtering
- [x] Reading GATT characteristics periodically
- [x] Receiving notifications from GATT characteristics
- [ ] Writing GATT characteristics

